==> haskell-monad-par-0.3.6-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-8FrGdfbYxKyD9I7nfAUaD6
key:                  monad-par-0.3.6-8FrGdfbYxKyD9I7nfAUaD6
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  e5322f175abbc7ac52712c17eb10bb18
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-8FrGdfbYxKyD9I7nfAUaD6
depends:
    abstract-deque-0.3-JTYgNVTi2rjIDdjAUIDJIb
    abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    monad-par-extras-0.3.3-7vN2yzUZh6Q5GloiFFGBNl mtl-2.2.2
    mwc-random-0.15.1.0-CrKXS58gA2w7swZUKXE4M0
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.6-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-par
version:              0.3.6
visibility:           public
id:                   monad-par-0.3.6-DLRgsJtgQU93AIP6AWhJgf
key:                  monad-par-0.3.6-DLRgsJtgQU93AIP6AWhJgf
license:              BSD-3-Clause
copyright:            (c) Simon Marlow 2011
maintainer:
    Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>

author:               Simon Marlow, Ryan Newton
stability:            Experimental
homepage:             https://github.com/simonmar/monad-par
synopsis:             A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.

    For complete documentation see "Control.Monad.Par".

    Some examples of use can be found in the @examples/@ directory of
    the source package.

    Other related packages:

    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.

    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.

    Changes in 0.3.4 relative to 0.3:

    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.

    * Added "Control.Monad.Par.IO"

category:             Control,Parallelism,Monads
abi:                  5fb261a3108eec1a12116c0b850fcd0b
exposed:              True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal

hidden-modules:       Control.Monad.Par.Scheds.DirectInternal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-par-0.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-par
hs-libraries:         HSmonad-par-0.3.6-DLRgsJtgQU93AIP6AWhJgf
depends:
    abstract-deque-0.3-Bj1mn7uMdGf3eR5rw5H0gr
    abstract-par-0.3.3-ISux4E1QYRJK5C39S1lmJd array-0.5.4.0
    base-4.16.4.0 containers-0.6.5.1 deepseq-1.4.6.1
    monad-par-extras-0.3.3-7buOLMhL19k1LhgmH2MNns mtl-2.2.2
    mwc-random-0.15.1.0-3LcBe3fj3h96l5Rtrl38iJ
    parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1

haddock-interfaces:   /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html:         /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
